# OATS

Optimization and Analysis Toolbox for power Systems (OATS) is a high-level modelling and simulation tool for power system analysis, developed at the [University of Strathclyde](https://www.strath.ac.uk/engineering/electronicelectricalengineering/). OATS is a collection of optimization models and Python scripts for analysis and solution of a range of power system analysis problems. 
<p align="center">
  <img  height="300" src="logo.png">
</p>

## Getting started
The scripts in OATS are written in Python 2. The optmization models are written in PYOMO, which is an algebraic modelling language. A solver is required to solve the optimization models. 

## Documentation
The [documentation](oatsdoc.pdf) of OATS is a best place to start. The documentation provides installation instructions and brief description of the optimization models that are implemented in OATS. 

## Contributing
Any issues with the code and/or software bugs in OATS should be raised through the GitHub page. 

Users are encourged to contribute to improve OATS. Contributions can be in the form of improved optimization models or in the form of data sets. 

Please note that the users are obliged to share the code derived from OATS under the license terms. 

## License

OATS is distributed under the open source license GNU GPL v3 - see the [LICENSE](LICENSE.md) file for details. This is a copyleft license that requires anyone using this code or a derivative work to make the source available under the same terms.

## Authors
* **Waqquas Bukhsh** - *Initial work* - [University of Strathclyde](https://github.com/bukhsh/)

See also the list of [contributors](https://github.com/bukhsh/oats/contributors) who participated in this project.

## Citing OATS

We are working on a journal article for OATS. Meanwhile, we request the users to cite the user manual of OATS.

* W. Bukhsh, OATS: Optimization and Analysis Toolbox for Power Systems Optimization, Documentation realease 0.1, 2017 \[Available\] Online: https://github.com/bukhsh/oats

## Acknowledgments

* [GARPUR](https://www.sintef.no/projectweb/garpur)
* [RESTLESS](http://gow.epsrc.ac.uk/NGBOViewGrant.aspx?GrantRef=EP/N001893/1)
* [University of Strathclyde](https://www.strath.ac.uk/)
